==> create-fly-6.0.7-1.21.8-19-sources.jar: com/zurrtum/create/client/content/contraptions/wrench/RadialWrenchHandler.java <==
package com.zurrtum.create.client.content.contraptions.wrench;

import com.zurrtum.create.AllItems;
import com.zurrtum.create.client.AllKeys;
import com.zurrtum.create.client.catnip.gui.ScreenOpener;
import net.minecraft.class_1799;
import net.minecraft.class_1934;
import net.minecraft.class_1937;
import net.minecraft.class_239;
import net.minecraft.class_2680;
import net.minecraft.class_310;
import net.minecraft.class_3675;
import net.minecraft.class_3965;
import net.minecraft.class_746;

public class RadialWrenchHandler {

    public static int COOLDOWN = 0;

    public static void clientTick() {
        if (COOLDOWN > 0 && !AllKeys.ROTATE_MENU.method_1434())
            COOLDOWN--;
    }

    public static void onKeyInput(class_310 mc, class_3675.class_306 key, boolean pressed) {
        if (!pressed)
            return;

        if (key != AllKeys.ROTATE_MENU.field_1655)
            return;

        if (COOLDOWN > 0)
            return;

        if (mc.field_1761 == null || mc.field_1761.method_2920() == class_1934.field_9219)
            return;

        class_746 player = mc.field_1724;
        if (player == null)
            return;

        class_1937 level = player.method_37908();

        class_1799 heldItem = player.method_6047();
        if (!heldItem.method_31574(AllItems.WRENCH))
            return;

        class_239 objectMouseOver = mc.field_1765;
        if (!(objectMouseOver instanceof class_3965 blockHitResult))
            return;

        class_2680 state = level.method_8320(blockHitResult.method_17777());

        RadialWrenchMenu.tryCreateFor(state, blockHitResult.method_17777(), level).ifPresent(ScreenOpener::open);
    }

}

==> create-fly-6.0.8-1.21.10-2-sources.jar: com/zurrtum/create/client/content/contraptions/wrench/RadialWrenchHandler.java <==
package com.zurrtum.create.client.content.contraptions.wrench;

import com.zurrtum.create.AllItems;
import com.zurrtum.create.client.AllKeys;
import com.zurrtum.create.client.catnip.gui.ScreenOpener;
import net.minecraft.class_11908;
import net.minecraft.class_1799;
import net.minecraft.class_1934;
import net.minecraft.class_1937;
import net.minecraft.class_239;
import net.minecraft.class_2680;
import net.minecraft.class_310;
import net.minecraft.class_3965;
import net.minecraft.class_746;

public class RadialWrenchHandler {

    public static int COOLDOWN = 0;

    public static void clientTick() {
        if (COOLDOWN > 0 && !AllKeys.ROTATE_MENU.method_1434())
            COOLDOWN--;
    }

    public static void onKeyInput(class_310 mc, class_11908 input, boolean pressed) {
        if (!pressed)
            return;

        if (!AllKeys.ROTATE_MENU.method_1417(input))
            return;

        if (COOLDOWN > 0)
            return;

        if (mc.field_1761 == null || mc.field_1761.method_2920() == class_1934.field_9219)
            return;

        class_746 player = mc.field_1724;
        if (player == null)
            return;

        class_1937 level = player.method_73183();

        class_1799 heldItem = player.method_6047();
        if (!heldItem.method_31574(AllItems.WRENCH))
            return;

        class_239 objectMouseOver = mc.field_1765;
        if (!(objectMouseOver instanceof class_3965 blockHitResult))
            return;

        class_2680 state = level.method_8320(blockHitResult.method_17777());

        RadialWrenchMenu.tryCreateFor(state, blockHitResult.method_17777(), level).ifPresent(ScreenOpener::open);
    }

}
